@@ -52,11 +52,24 @@ def get_project_configuration():
     """Get project configuration as dictionary."""
     home = os.path.expanduser("~")
     rcfile = os.path.join(home, ".writemathrc")
+    if not os.path.isfile(rcfile):
+        create_project_configuration(rcfile)
     with open(rcfile, 'r') as ymlfile:
         cfg = yaml.load(ymlfile)
     return cfg
 
 
+def create_project_configuration(filename):
+    home = os.path.expanduser("~")
+    writemath = os.path.join(home, "writemath")
+    config = {'root': writemath,
+              'nntoolkit': None,
+              'dropbox_app_key': None,
+              'dropbox_app_secret': None}
+    with open(filename, 'w') as f:
+        yaml.dump(config, f, default_flow_style=False)
+
+
 def get_project_root():
     """Get the project root folder as a string."""
     cfg = get_project_configuration()
